# pi-topSPEAKER

Available from the [pi-top website](https://pi-top.com/products/accessories).

# Hardware
## Overview
Each pi-topSPEAKER is manufactured identically, but it is a modular device and up to 3 can be connected in a chain. pi-topSPEAKER needs to be initialised each time after power up in order to function. 

## Some more information
To avoid overlapping of I2C addresses there is a 3-position hardware switch that the user can set to select L, M or R - left channel, mono mix or right channel respectively. This switch changes the primary I2C address of the pi-topSPEAKER, which means that there is a direct mapping between the I2C address and the channel to be output through that particular instance of pi-topSPEAKER.

Communicating with a pi-topSPEAKER requires an initial communication via an I2C MUX. The I2C MUX can be thought of as a proxy: first, it is necessary to open up the proxy by writing which channel you wish to be opened up (always channel 0). This then connects the pi-topSPEAKER 'brain' directly to the I2C bus, and communication can be carried out as normal. The proxy must be closed before trying to communicate with other pi-topSPEAKERs.

# Software
## pi-topOS
All pi-topSPEAKER software and libraries are included and configured 'out-of-the-box' as standard on the latest version of pi-topOS (>= 23-06-2017).

Download the latest version of pi-topOS at [https://pi-top.com/get-started](https://pi-top.com/get-started).

### Summary
Everything is already configured to work out-of-the-box! Simply connect a pi-topSPEAKER to your pi-top and - so long as you are using the default sound drivers - it will be automatically initialised and ready to make noises using the audio channel of the HDMI connection to the pi-topHUB. Volume control is handled by the operating system.
### Some more information
This automatic initialisation is done by a software package called `pt-peripheral-cfg`. It contains a program called `pt-peripherals-daemon`, which runs in the background and scans for newly connected devices. If a device is detected, and the appropriate library is installed allow it to be initialised, it will run the approprate command. The `pt-speaker` package on pi-topOS installs and starts this background process, as well as the Python library to allow the pi-topSPEAKER to be initialised when detected. In the case of pi-topSPEAKER, it checks the I2C lines, and - on detection - will ensure that HDMI is set as audio output, and initialise.

## Raspbian
You can add pi-topSPEAKER functionality by adding the ability to download from the pi-top software repository to your pi-top, and installing the software to work in the same plug-and-play way as on pi-topOS. Simply run the following commands at the terminal:

```
wget http://apt.pi-top.com/add
sudo bash add
sudo apt-get install pt-speaker
```

If you prefer to manually install the packages or want to install a specific set of packages see the [advanced installations page](https://github.com/pi-top/pi-topSPEAKER/wiki/Advanced-Installation-Methods).

## How it works - 'under the hood'
The library files in this repository make up a Python module which can be used to initialise the pi-topSPEAKER. There is only one function intended to be used: `enable()`.

`configuration.py` is the module to import, and is designed to be placed inside a folder, which can either be placed in the same location as the file that you want to run, or inside of the appropriate `dist-packages` folder for the version of Python that you are running (**ADD LINK TO INFORMATION ON THIS**). 

Assuming that you have done this correctly, you should be able to initialise the pi-topSPEAKER with a Python program that looks something like this:

```
from ptspeaker import configuration as ptspeakercfg

if ptspeakercfg.enable():
    print("Successfully enabled pi-topSPEAKER")
else:
    print("Failed to enable pi-topSPEAKER")
```
**NOTE: all examples assume that the folder that the library is in is named** `ptspeaker` **- change as appropriate if required.**

The enable function reads the `setup.cfg` file in the library folder (which is a series of instructions to configure the pi-topSPEAKER) and sending corresponding commands to the device.

# Documentation & Support

** MAKE SURE THAT THESE ARE READY **

* Function reference - http://docs.pimoroni.com/ptpulse/
* GPIO Pinout - http://pinout.xyz/pinout/ptpulse
* Get help - http://support.pi-top.com/support/login/